#! /usr/bin/perl
use strict;
use warnings;
#///////////////////////////////////////////////////////////////////
#/								   /
#/   IBL_THmon                                                     /
#/								   /
#/   Monitor each sensor and send alert if a sensor goes into      /
#/   alarm.                                                        /  
#/                                                                 /
#/  The only parameter is the communications device of the master  /
#/  For a Windows serial master (Link45/LinkUSB/LinkOEM)           /
#/    specify the device as \\.\COMx where x is the com port.      /
#/  For a Linux serial master (Link45/LinkUSB/LinkOEM)             /
#/    specify the device as /dev/ttyUSBx where x is the device.    /
#/    typically this will be /dev/ttyUSB0                          /
#/  If no parameter is supplied, IBL_demo will default to a        /
#/    LinkHub-E at address 67.53.90.115 port 10001                 /
#/                                                                 /
#/   Future:If the parameter begins with config=                   /
#/      It is the name of a configuration file and the             /
#/      communications device will be extracted from it.           /
#/                                                                 /
#/   This is a simple monitoring program.  It sends an alert       /
#/   if a temperature or humidity reading is above a setpoint      /
#/   or lower than a setpoint.                                     /
#/                                                                 /
#/   No provision is provided to alert when the sensor regains     /
#/   a normal range or to debouce alerts.                          /
#/                                                                 /
#/   I probably will add them later, but wanted more to get this   /
#/   out the door so you would have something to look at.          /
#/							           /
#/   Copyright 2010 ... iButtonLink LLC                            /
#/   All rights reserved					   /
#/   N8921 Stone School Rd.					   /
#/   East Troy, Wi. 53120                                          /
#/   United States of America                                      /
#/   Phone (262)662-4029					   /
#/   Fax:  (262)436-2403					   /
#/                                                                 /
#/   Kindly direct comments, etc to support@iButtonLink.com        /
#/								   /
#///////////////////////////////////////////////////////////////////
use IBL;                        # The iButtonLink subroutine package
my  $Tscale = "F";              # Report temperature in American
my  $IBmaster;                  # Object from IBL.pm
my  $cm;                        # A place to store the channel mask
my  $ok;
my  $IBLdev;
my  ($x, @x);                   # Scratchpad scalar and array
my  %HSN;
my  $hub = 0;                   # If 1, the IBL master is a LinkHub
my  ($key,$value,$result);
my  @alert_lines=();            # an empty array
my  $Thigh = 85.0;              # High temperature alert setpoint
my  $Tlow = 35.0;               # Low temperature alert setupoint
my  $Hhigh = 60.0;              # High humidity alaert setpoint
my  $Hlow = 15.0;               # Low humidity alert setpoint


#/////////////////////////////////////////////////////////
#/   Get Link device name from command line argument 1   /
#/   If not specificed, default to 67.53.90.115:10001    /
#/////////////////////////////////////////////////////////
$IBLdev = shift || '67.53.90.115:10001';
$IBmaster = new IBL ;
$IBmaster->device($IBLdev);
if (index($IBLdev,'COM') != -1) {         # Test for a Link45/LinkUSB on a Windows serial port
  $IBmaster->interface("Serial");
} elsif (index($IBLdev,'tty')!= -1) {     # Test for a Link45/LinkUSB on a Linux serial port
  $IBmaster->interface("Serial");
} else {
  $IBmaster->interface("Telnet");         # Default to Telnet over IP
  $hub = 1;                               # Default to LinkHub-E
}


$ok = $IBmaster->open();
$x = $IBmaster->master;
print "The master is: $x\n";

#/////////////////////////////////////////////
#/   Make sure channel mask is set to 0x37   /
#/   if we are dealing with a LinkHub-E      /
#/////////////////////////////////////////////
if ($hub == 1) {
  $ok = $IBmaster->write('\c');
  $cm = $IBmaster->readline;
  $ok = $IBmaster->write('\C37');
  $x = $IBmaster->readline;
}
$x = 0;
$IBmaster->ConvertT();
$IBmaster->ConvertV();
%HSN = $IBmaster->ClassifyedInventory;      # Get a hash of classified sensors

   while (($key, $value) = each(%HSN)) {
      $result = $IBmaster->Read_Sensor($key, $value);

     if($result)
     {
      if (index ($value,'T') != -1) {       # Process a temperature sensor
        @x = split(/,/,$result);
        if ($x[1] > $Thigh) { push (@alert_lines, "$key High Temperature Alarm value: $x[1]\n"); }
        if ($x[1] < $Tlow)  { push (@alert_lines, "$key Low  Temperature Alarm value: $x[1]\n"); }
      }
      
      if (index ($value,'H') != -1) {       # Process a humidity reading
        @x = split(/,/,$result);
        if ($x[2] > $Hhigh) { push (@alert_lines, "$key High Humidity Alarm value: $x[2]\n"); }
        if ($x[2] < $Hlow)  { push (@alert_lines, "$key Low  Humidity Alarm value: $x[2]\n"); }
      }
      
      print "$key,$result\n";
    }
    else
    {
       print "$key,ERROR\n";
    }
   }

   print "End of Report\n";
   if (@alert_lines) {send_alert(\@alert_lines)}   # Send alarm if something in the body array
                                                    # Note the pass by reference
#////////////////////////////////////////////
#/   Put channel mask back if a LinkHub-E   /
#////////////////////////////////////////////
if ($hub == 1) {
   $x = '\C' . $cm;
   $IBmaster->write($x);                    # Restore the channel mask
   $x = $IBmaster->readline(2.0);
}
exit 0;
#////////////////////////////////////////////
#/                                          /
#/   Send_alert ...  An email alert is      /
#/                   illustrated to my      /
#/                   cell phone             /
#/                                          /
#/   Send this routine an array of lines    /
#/   representing the body of the alert     /
#/                                          /
#////////////////////////////////////////////
sub send_alert {
  use Net::SMTP;
  my  @lines = shift;            # Get the array of lines passed in

my $smtp = Net::SMTP->new('ns1.wcf.net'); # connect to an SMTP server
  $smtp->mail('farmer@wcf.net');       # use the sender's address here
  $smtp->to('2627451201@messaging.sprintpcs.com'); # recipient's address
  $smtp->to('bfarmer@wcfa.com');       # Recipient's address
  $smtp->data();                       # Start the mail

  # Send the header.
  $smtp->datasend("To: Sensor Alert list\n");
  $smtp->datasend("From: farmer\@wcf.net\n");
  $smtp->datasend("Subject: Sensor alert\n");
  $smtp->datasend("\n");

  # Send the body.
  $smtp->datasend(@lines);
  $smtp->dataend();                   # Finish sending the mail
  $smtp->quit;                        # Close the SMTP connection
  
  return;
}
