#! /usr/bin/perl
use strict;
use warnings;
#///////////////////////////////////////////////////////////////////
#/								   /
#/   IBL_demo                                                      /
#/								   /
#/   Do an inventory of the bus and report sensor type and value.  /
#/                                                                 /
#/  The only parameter to this script is the communications device /
#/  For a Windows serial master (Link45/LinkUSB/LinkOEM)           /
#/    specify the device as \\.\COMx where x is the com port.      /
#/  For a Linux serial master (Link45/LinkUSB/LinkOEM)             /
#/    specify the device as /dev/ttyUSBx where x is the device.    /
#/    typically this will be /dev/ttyUSB0                          /
#/  If no parameter is supplied, IBL_demo will default to a        /
#/    LinkHub-E at address 67.53.90.115 port 10001                 /
#/							           /
#/   Copyright 2010 ... iButtonLink LLC                            /
#/   All rights reserved					   /
#/   N8921 Stone School Rd.					   /
#/   East Troy, Wi. 53120                                          /
#/   United States of America                                      /
#/   Phone (262)662-4029					   /
#/   Fax:  (262)436-2403					   /
#/                                                                 /
#/   Kindly direct comments, etc to support@iButtonLink.com        /
#/								   /
#///////////////////////////////////////////////////////////////////
use IBL;                        # The iButtonLink subroutine package
my  $Tscale = "C";              # Report temperature in American
my  $IBmaster;                  # Object from IBL.pm
my  $cm;                        # A place to store the channel mask
my  $ok;
my  $IBLdev;
my  $x;
my  %HSN;
my  $hub = 0;                   # If 1, the IBL master is a LinkHub
my  ($key,$value,$result);

#/////////////////////////////////////////////////////////
#/   Get Link device name from command line argument 1   /
#/   If not specificed, default to 67.53.90.115:10001    /
#/////////////////////////////////////////////////////////
$IBLdev = shift || '67.53.90.115:10001';
$IBmaster = new IBL ;
$IBmaster->device($IBLdev);
if (index($IBLdev,'COM') != -1) {         # Test for a Link45/LinkUSB on a Windows serial port
  $IBmaster->interface("Serial");
} elsif (index($IBLdev,'tty')!= -1) {     # Test for a Link45/LinkUSB on a Linux serial port
  $IBmaster->interface("Serial");
} else {
  $IBmaster->interface("Telnet");         # Default to Telnet over IP
  $hub = 1;                               # Default to LinkHub-E
}


$ok = $IBmaster->open();
$x = $IBmaster->master;
print "The master is: $x\n";

#/////////////////////////////////////////////
#/   Make sure channel mask is set to 0x37   /
#/   if we are dealing with a LinkHub-E      /
#/////////////////////////////////////////////
if ($hub == 1) {
  $ok = $IBmaster->write('\c');
  $cm = $IBmaster->readline;
  $ok = $IBmaster->write('\C37');
  $x = $IBmaster->readline;
}
$x = 0;
$IBmaster->ConvertT();
$IBmaster->ConvertV();
%HSN = $IBmaster->ClassifyedInventory;      # Get a hash of classified sensors

   while (($key, $value) = each(%HSN)) {
      $result = $IBmaster->Read_Sensor($key, $value);
      print "$key,$result\n";
   }
   print "End of Report\n";
#////////////////////////////////////////////
#/   Put channel mask back if a LinkHub-E   /
#////////////////////////////////////////////
if ($hub == 1) {
   $x = '\C' . $cm;
   $IBmaster->write($x);                    # Restore the channel mask
   $x = $IBmaster->readline(2.0);
}
exit 0;
